pub enum SchemaType {
Bytes,
String,
Number,
Avro,
JsonSchema,
Protobuf,
}Expand description
Schema types supported by the registry
Variants
Bytes
Raw bytes - no schema validation Use for binary data or custom serialization
String
UTF-8 string - validates string encoding Use for plain text messages
Number
Numeric types (int, long, float, double) Validates numeric data
Avro
Apache Avro schema format Structured binary format with schema evolution support
JsonSchema
JSON Schema format JSON-based schema validation
Protobuf
Protocol Buffers schema format Google’s language-neutral serialization format
Implementations