pub struct SchemaRegistrationBuilder<'a> { /* private fields */ }Expand description
Builder for schema registration with fluent API.
Example
use danube_client::{DanubeClient, SchemaType};
let client = DanubeClient::builder()
.service_url("http://localhost:6650")
.build()
.await?;
let schema_id = client.schema()
.register_schema("user-events-value")
.with_type(SchemaType::Avro)
.with_schema_data(avro_schema_bytes)
.execute()
.await?;Schema Versioning
The registry automatically handles versioning:
- If the schema definition is new, a new version is created
- If the schema definition already exists, the existing schema_id and version are returned
- Compatibility checks are performed based on the subject’s compatibility mode
Implementations
Sourceimpl<'a> SchemaRegistrationBuilder<'a>
impl<'a> SchemaRegistrationBuilder<'a>
Sourcepub fn with_type(self, schema_type: SchemaType) -> Self
pub fn with_type(self, schema_type: SchemaType) -> Self
Set the schema type
Sourcepub fn with_schema_data(self, data: impl Into<Vec<u8>>) -> Self
pub fn with_schema_data(self, data: impl Into<Vec<u8>>) -> Self
Set the schema data (raw schema content)
Sourcepub fn with_description(self, description: impl Into<String>) -> Self
pub fn with_description(self, description: impl Into<String>) -> Self
Set an optional description for the schema
Sourcepub fn with_created_by(self, created_by: impl Into<String>) -> Self
pub fn with_created_by(self, created_by: impl Into<String>) -> Self
Set who created the schema (defaults to “danube-client”)
Set tags for the schema